@@ -8,9 +8,22 @@ from git_speed import cli
 HOME = str(pathlib.Path.home())
 ALIAS_INSTALL_PATH = HOME + "/.git_aliases"
 BASHRC = HOME + "/.bashrc"
+START = "# Managed by git-speed: start"
+END = "# Managed by git-speed: end"
 
 
 def install():
+    with open(BASHRC, "r") as f:
+        for line in f:
+            if START in line:
+                reinstall = typer.confirm(
+                    "git-speed is already installed. Do you want to reinstall it?"
+                )
+                if not reinstall:
+                    cli.info("Not reinstalling.")
+                    raise typer.Abort()
+                uninstall()
+
     if os.path.exists(ALIAS_INSTALL_PATH):
         delete = typer.confirm(
             f"{ALIAS_INSTALL_PATH} already exists. Do you want to delete it?"
@@ -27,7 +40,14 @@ def install():
     with open(BASHRC, "a") as f:
         f.write(
             f"""
-# Added by git-speed
+{START}
+# See https://pypi.org/project/git-speed/ for more information.
+"""
+        )
+
+    with open(BASHRC, "a") as f:
+        f.write(
+            r"""
 if [ -f ~/.git_aliases ]; then
     . ~/.git_aliases
 fi
@@ -37,14 +57,14 @@ fi
     cli.success("Installed aliases.")
 
     install_prompt = typer.confirm(
-        "Would you like to add your current Git branch to your Bash prompt?"
+        "Would you like to add your current Git branch to your Bash prompt?",
+        default=True,
     )
 
     if install_prompt:
         with open(BASHRC, "a") as f:
             f.write(
                 r"""
-# Added by git-speed
 if [ -x /usr/bin/tput ] && tput setaf 1 >&/dev/null; then
     # We have color support; assume it's compliant with Ecma-48
     # (ISO/IEC-6429). (Lack of such support is extremely rare, and such
@@ -54,17 +74,14 @@ else
     color_prompt=
 fi
 
-# Added by git-speed
 parse_git_dirty() {
     [[ $(git status 2> /dev/null | tail -n1) != "nothing to commit"* ]] && echo "~"
 }
 
-# Added by git-speed
 parse_git_branch() {
     git rev-parse --abbrev-ref HEAD 2> /dev/null | sed "s/\(.*\)/(\1$(parse_git_dirty))/"
 }
 
-# Added by git-speed
 if [ "$color_prompt" = yes ]; then
     user_style='01;32m'
     dir_style='01;34m'
@@ -77,4 +94,36 @@ fi
 unset color_prompt
 """
             )
+
+    with open(BASHRC, "a") as f:
+        f.write(
+            f"""
+{END}
+"""
+        )
         cli.success("Updated Bash prompt.")
+
+
+def uninstall():
+    os.remove(ALIAS_INSTALL_PATH)
+    cli.info(f"Deleted {ALIAS_INSTALL_PATH}.")
+
+    out = []
+    with open(BASHRC, "r") as f:
+        lines = f.readlines()
+
+    append = True
+    for line in lines:
+        if START in line:
+            append = False
+            if out[-1] == "\n":
+                out = out[:-1]
+        if append:
+            out.append(line)
+        if END in line:
+            append = True
+
+    with open(BASHRC, "w") as f:
+        f.writelines(out)
+
+    cli.info("Removed git-speed from your .bashrc.")
